@@ -2,7 +2,7 @@
     FAST - Copyright (c) 2016 ONERA ISAE
 """
 #  This file is part of FAST-OAD : A framework for rapid Overall Aircraft Design
-#  Copyright (C) 2020  ONERA & ISAE-SUPAERO
+#  Copyright (C) 2021 ONERA & ISAE-SUPAERO
 #  FAST is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -17,14 +17,16 @@
 import numpy as np
 import openmdao.api as om
 
-from fastoad.models.weight.cg.cg_components import ComputeControlSurfacesCG
-from fastoad.models.weight.cg.cg_components import ComputeGlobalCG
-from fastoad.models.weight.cg.cg_components import ComputeHTcg
-from fastoad.models.weight.cg.cg_components import ComputeOthersCG
-from fastoad.models.weight.cg.cg_components import ComputeTanksCG
-from fastoad.models.weight.cg.cg_components import ComputeVTcg
-from fastoad.models.weight.cg.cg_components import ComputeWingCG
-from fastoad.models.weight.cg.cg_components import UpdateMLG
+from fastoad.models.weight.cg.cg_components import (
+    ComputeControlSurfacesCG,
+    ComputeGlobalCG,
+    ComputeHTcg,
+    ComputeOthersCG,
+    ComputeTanksCG,
+    ComputeVTcg,
+    ComputeWingCG,
+    UpdateMLG,
+)
 
 
 class CG(om.Group):
@@ -60,6 +62,7 @@ class ComputeAircraftCG(om.ExplicitComponent):
 
         self.add_output("data:weight:aircraft:CG:aft:x", units="m")
 
+    def setup_partials(self):
         self.declare_partials("*", "*", method="fd")
 
     def compute(self, inputs, outputs):
